@@ -11,11 +11,12 @@ select_greedy <- function(pairs, variable, score, threshold, preselect = NULL,
 #' @export
 select_greedy.pairs <- function(pairs, variable, score, threshold, preselect = NULL, 
     id_x = NULL, id_y = NULL, x = attr(pairs, "x"), y = attr(pairs, "y"), 
-    inplace = FALSE, include_ties = FALSE, n = 1L, m = 1L, ...) {
+    inplace = FALSE, include_ties = FALSE, n = 1L, m = 1L, 
+    deduplication = val_or(attr(pairs, "deduplication"), FALSE), ...) {
   prep <- select_preprocess(pairs, score = score, threshold = threshold, 
     preselect = preselect, id_x = id_x, id_y = id_y, x = x, y = y)
   sel <- greedy(prep$.x, prep$.y, prep$score, include_ties = include_ties, 
-    n = n, m = m)
+    n = n, m = m, deduplication = deduplication)
   if (inplace) {
     pairs[, (variable) := FALSE]
     pairs[prep$index[sel], (variable) := TRUE]
