@@ -3,7 +3,6 @@
 #
 select_preprocess <- function(pairs, score, threshold = NULL, preselect = NULL, 
     id_x = NULL, id_y = NULL, x = attr(pairs, 'x'), y = attr(pairs, 'y')) {
-  
   if (is.character(score)) {
     stopifnot(score %in% names(pairs))
     score <- pairs[[score]]
@@ -28,11 +27,12 @@ select_preprocess <- function(pairs, score, threshold = NULL, preselect = NULL,
   } else id_y <- pairs$.y
   stopifnot(length(id_y) == length(select))
   # Select possible matches
-  data.table(
+  res <- data.table(
     .x = id_x[select],
     .y = id_y[select],
     score = score[select],
     index = which(select)
   )
+  res
 }
 
